/*
Blueprint Manager 
Version 1.00
Written by F22-Raptor-2006
*/

if bmf != undefined then closeRolloutFloater bmf
(
	function fn_findAllPlanes = 
	(
		tp = for o in objects where matchpattern o.name pattern:"XX_BP_*" collect o
		return tp
	)
	
	function fn_findPlane thePlane = 
	(
		tp = for o in objects where matchpattern o.name pattern:thePlane collect o
		return tp
	)
	
	function fn_createPlanes topPlane bottomPlane frontPlane backPlane leftPlane rightPlane =
	(
		planesArray = #(topPlane,bottomPlane,frontPlane,backPlane,leftPlane,rightPlane)
		namePrefix = #("XX_BP_TOP_","XX_BP_BOTTOM_","XX_BP_FRONT_","XX_BP_BACK_","XX_BP_LEFT_","XX_BP_RIGHT_")
		
		for i = 1 to planesArray.count do
		(
			if planesArray[i] != "" then
			(
				imgFile = planesArray[i]
				tempMap = openbitmap imgFile

				imgPlane = plane name:(namePrefix[i] + getfilenamefile imgFile) length:(tempMap.height) width:(tempMap.width) lengthsegs:1 widthsegs:1 mapCoords:true isselected:true
				imgPlane.showFrozenInGray = off
				imgPlane.backfacecull = on
				imgPlane.renderable = off 
				imgPlane.wirecolor = color 88 177 26

				imgMaterial = standard()
				imgMaterial.name = imgPlane.name
				imgMaterial.selfIllumAmount = 100
				
				imgTexture = bitmaptexture()
				imgTexture.bitmap = tempMap
				
				imgMaterial.diffuseMap = imgTexture
				imgMaterial.twoSided = on
					
				imgPlane.material = imgMaterial

				showTextureMap imgMaterial imgMaterial.diffuseMap on 
				close tempMap
				
				case of
				(
					(i == 1): -- top plane
						(
							imgPlane.rotation = eulerangles 0 0 0
							imgPlane.pivot = (imgPlane.max + imgPlane.min)/2
							imgPlane.pos = [0,0,0] 
						)
					(i == 2): -- bottom plane
						(
							imgPlane.rotation = eulerangles 0 180 0
							imgPlane.pivot = (imgPlane.max + imgPlane.min)/2
							imgPlane.pos = [0,0,0] 
						)
					(i == 3): -- front plane
						(
							imgPlane.rotation = eulerangles -90 0 0
							imgPlane.pivot = (imgPlane.max + imgPlane.min)/2
							imgPlane.pivot.z = imgPlane.min.z
							imgPlane.pos = [0,0,0] 
						)
					(i == 4):  -- back plane
						(
							imgPlane.rotation = eulerangles -90 180 0
							imgPlane.pivot = (imgPlane.max + imgPlane.min)/2
							imgPlane.pivot.z = imgPlane.min.z
							imgPlane.pos = [0,0,0] 
						)
					(i == 5): -- left plane
						(
							imgPlane.rotation = eulerangles 0 90 90
							imgPlane.pivot = (imgPlane.max + imgPlane.min)/2
							imgPlane.pivot.z = imgPlane.min.z
							imgPlane.pos = [0,0,0] 
						)
					(i == 6): -- right plane
						(
							imgPlane.rotation = eulerangles 0 -90 -90
							imgPlane.pivot = (imgPlane.max + imgPlane.min)/2
							imgPlane.pivot.z = imgPlane.min.z
							imgPlane.pos = [0,0,0] 
						)
				)
				max views redraw
			)
		)
		
		clearSelection()
		for p in fn_findAllPlanes() do selectmore p
		
		try(fn_findPlane "XX_BP_BOTTOM_*")[1].pos.z = selection.max.z catch()
		try(fn_findPlane "XX_BP_FRONT_*")[1].pos.y = selection.max.y catch()
		try(fn_findPlane "XX_BP_BACK_*")[1].pos.y = selection.min.y catch()
		try(fn_findPlane "XX_BP_LEFT_*")[1].pos.x = selection.max.x catch()
		try(fn_findPlane "XX_BP_RIGHT_*")[1].pos.x = selection.min.x catch()
	)
	
	rollout rlt_planeCreation "Plane Creation"
	(
		group "Source Images"
		(
			label lbl_imgTop "Top Image: " align:#left
			edittext txt_imgTop "" width:195 across:2
			button btn_browseTop "Browse" width:60 align:#right
			
			label lbl_imgBottom "Bottom Image: " align:#left
			edittext txt_imgBottom "" width:195 across:2
			button btn_browseBottom "Browse" width:60 align:#right
			
			label lbl_imgFront "Front Image: " align:#left
			edittext txt_imgFront "" width:195 across:2
			button btn_browseFront "Browse" width:60 align:#right
			
			label lbl_imgBack "Back Image: " align:#left
			edittext txt_imgBack "" width:195 across:2
			button btn_browseBack "Browse" width:60 align:#right
			
			label lbl_imgLeft "Left Image: " align:#left
			edittext txt_imgLeft "" width:195 across:2
			button btn_browseLeft "Browse" width:60 align:#right
			
			label lbl_imgRight "Right Image: " align:#left
			edittext txt_imgRight "" width:195 across:2
			button btn_browseRight "Browse" width:60 align:#right
		)
		
		button btn_createPlanes "Create Blueprint Planes" height:40 width:279
		
		on btn_browseTop pressed do
		(
			theFile = getOpenFileName()
			if theFile != undefined then txt_imgTop.text = theFile
		)
		
		on btn_browseBottom pressed do
		(
			theFile = getOpenFileName()
			if theFile != undefined then txt_imgBottom.text = theFile
		)
		
		on btn_browseFront pressed do
		(
			theFile = getOpenFileName()
			if theFile != undefined then txt_imgFront.text = theFile
		)
		
		on btn_browseBack pressed do
		(
			theFile = getOpenFileName()
			if theFile != undefined then txt_imgBack.text = theFile
		)
		
		on btn_browseLeft pressed do
		(
			theFile = getOpenFileName()
			if theFile != undefined then txt_imgLeft.text = theFile
		)
		
		on btn_browseRight pressed do
		(
			theFile = getOpenFileName()
			if theFile != undefined then txt_imgRight.text = theFile
		)
		
		on btn_createPlanes pressed do
		(
			existingPlanes = fn_findAllPlanes()
			
			if existingPlanes.count == 0 then
			(
			fn_createPlanes txt_imgTop.text txt_imgBottom.text txt_imgFront.text txt_imgBack.text txt_imgLeft.text txt_imgRight.text
				
			txt_imgTop.text = ""
			txt_imgBottom.text = ""
			txt_imgFront.text = ""
			txt_imgBack.text = ""
			txt_imgLeft.text = ""
			txt_imgRight.text = ""
			)
			else messagebox "There are already blueprint planes in the scene!"
 		)
	)

	rollout rlt_planeManagement "Plane Management"
	(
		group "By Selection"
		(
			checkbox chk_top "Top" across:3 
			checkbox chk_front "Front"
			checkbox chk_left "Left"
			checkbox chk_bottom "Bottom" across:3 
			checkbox chk_back "Back"
			checkbox chk_right "Right"
			
			button btn_hideSelected "Hide Selected" across:2 width:130 offset:[-3,0]
			button btn_unhideSelected "Unhide Selected" width:130 offset:[3,0]
			
			button btn_freezeSelected "Freeze Selected" across:2 width:130 offset:[-3,0]
			button btn_unfreezeSelected "Unfreeze Selected" width:130 offset:[4,0]
		)
		
		group "Global"
		(
			button btn_hidePlanes "Hide All Planes" across:2 width:130 offset:[-3,0]
			button btn_unhidePlanes "Unhide All Planes" width:130 offset:[3,0]
			
			button btn_freezePlanes "Freeze All Planes" across:2 width:130 offset:[-3,0]
			button btn_unfreezePlanes "Unfreeze All Planes" width:130 offset:[4,0]
		)
		
		on btn_hideSelected pressed do
			(
				if chk_top.checked == true then try hide (fn_findPlane "XX_BP_TOP_*")[1] catch()
				if chk_front.checked == true then try hide (fn_findPlane "XX_BP_FRONT_*")[1] catch()
				if chk_left.checked == true then try hide (fn_findPlane "XX_BP_LEFT_*")[1] catch()
				if chk_bottom.checked == true then try hide (fn_findPlane "XX_BP_BOTTOM_*")[1] catch()
				if chk_back.checked == true then try hide (fn_findPlane "XX_BP_BACK_*")[1] catch()
				if chk_right.checked == true then try hide (fn_findPlane "XX_BP_RIGHT_*")[1] catch()
			)
			
		on btn_unhideSelected pressed do
			(
				if chk_top.checked == true then try unhide (fn_findPlane "XX_BP_TOP_*")[1] catch()
				if chk_front.checked == true then try unhide (fn_findPlane "XX_BP_FRONT_*")[1] catch()
				if chk_left.checked == true then try unhide (fn_findPlane "XX_BP_LEFT_*")[1] catch()
				if chk_bottom.checked == true then try unhide (fn_findPlane "XX_BP_BOTTOM_*")[1] catch()
				if chk_back.checked == true then try unhide (fn_findPlane "XX_BP_BACK_*")[1] catch()
				if chk_right.checked == true then try unhide (fn_findPlane "XX_BP_RIGHT_*")[1] catch()
			)
			
		on btn_freezeSelected pressed do
			(
				if chk_top.checked == true then try freeze (fn_findPlane "XX_BP_TOP_*")[1] catch()
				if chk_front.checked == true then try freeze (fn_findPlane "XX_BP_FRONT_*")[1] catch()
				if chk_left.checked == true then try freeze (fn_findPlane "XX_BP_LEFT_*")[1] catch()
				if chk_bottom.checked == true then try freeze (fn_findPlane "XX_BP_BOTTOM_*")[1] catch()
				if chk_back.checked == true then try freeze (fn_findPlane "XX_BP_BACK_*")[1] catch()
				if chk_right.checked == true then try freeze (fn_findPlane "XX_BP_RIGHT_*")[1] catch()
			)
			
		on btn_unfreezeSelected pressed do
			(
				if chk_top.checked == true then try unfreeze (fn_findPlane "XX_BP_TOP_*")[1] catch()
				if chk_front.checked == true then try unfreeze (fn_findPlane "XX_BP_FRONT_*")[1] catch()
				if chk_left.checked == true then try unfreeze (fn_findPlane "XX_BP_LEFT_*")[1] catch()
				if chk_bottom.checked == true then try unfreeze (fn_findPlane "XX_BP_BOTTOM_*")[1] catch()
				if chk_back.checked == true then try unfreeze (fn_findPlane "XX_BP_BACK_*")[1] catch()
				if chk_right.checked == true then try unfreeze (fn_findPlane "XX_BP_RIGHT_*")[1] catch()
			)
			
		on btn_hidePlanes pressed do for i in fn_findAllPlanes() do hide i
		on btn_unhidePlanes pressed do for i in fn_findAllPlanes() do unhide i
		on btn_freezePlanes pressed do for i in fn_findAllPlanes() do freeze i
		on btn_unfreezePlanes pressed do for i in fn_findAllPlanes() do unfreeze i
	)
	
	rollout rlt_about "About"
	(
		label lbl_version "Version 1.00"
		label lbl_writtenFor "Written for" across:2 offset:[8,0]
		hyperlink lnk_SAS "Special Aircraft Service" address:"http://www.sas1946.com/main/index.php" offset:[-26,0] color:(color 0 0 255)
		
		label lbl_spacer ""
		label lbl_date "Date released: 17th February 2011"
		label lbl_spacer2 ""
		label lbl_writtenBy"Written by: F22-Raptor-2006"
	)

	
bmf = newRolloutFloater "Blueprint Manager" 300 620
addRollout rlt_planeCreation bmf rolledup: false
addRollout rlt_planeManagement bmf rolledup: false
addRollout rlt_about bmf rolledup: true
)
